@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 from flask import Markup, url_for
 from babel.dates import format_date, format_datetime
 
@@ -58,7 +60,7 @@ class Col(object):
         self.attr_list = attr_list
         if attr:
             self.attr_list = attr.split('.')
-        
+
         Col._counter += 1
 
     def get_attr_list(self, attr):
@@ -77,7 +79,8 @@ class Col(object):
             return out
 
     def td(self, i, attr):
-        return '<td>%s</td>' % self.td_contents(i, self.get_attr_list(attr))
+        return '<td>{}</td>'.format(
+            self.td_contents(i, self.get_attr_list(attr)))
 
     def td_contents(self, i, attr_list):
         """Given an item and an attr, return the contents of the
@@ -110,7 +113,8 @@ class Col(object):
 
 
 class OptCol(Col):
-    def __init__(self, name, choices={}, default_key=None, default_value='', coerce_fn=None, **kwargs):
+    def __init__(self, name, choices={}, default_key=None, default_value='',
+                 coerce_fn=None, **kwargs):
         Col.__init__(self, name, **kwargs)
         self.choices = choices
         self.default_value = choices.get(default_key, default_value)
@@ -123,12 +127,14 @@ class OptCol(Col):
             return content
 
     def td_format(self, content):
-        return self.choices.get(self.coerce_content(content), self.default_value)
+        return self.choices.get(
+            self.coerce_content(content), self.default_value)
 
 
 class BoolCol(OptCol):
     def __init__(self, name, **kwargs):
-        OptCol.__init__(self, name, choices={True: 'Yes', False: 'No'}, coerce_fn=bool, **kwargs)
+        OptCol.__init__(self, name, choices={True: 'Yes', False: 'No'},
+                        coerce_fn=bool, **kwargs)
 
 
 class DateCol(Col):
@@ -177,7 +183,8 @@ class LinkCol(Col):
     id=item.id) for each item in the iterable.
 
     """
-    def __init__(self, name, endpoint, attr=None, attr_list=[], url_kwargs={}, **kwargs):
+    def __init__(self, name, endpoint, attr=None, attr_list=[], url_kwargs={},
+                 **kwargs):
         Col.__init__(self, name, attr=attr, attr_list=attr_list, **kwargs)
         self.endpoint = endpoint
         self._url_kwargs = url_kwargs
@@ -201,8 +208,9 @@ class LinkCol(Col):
         return url_for(self.endpoint, **self.url_kwargs(i))
 
     def td_contents(self, i, attr_list):
-        return '<a href="%s">%s</a>' % (self.url(i),
-                                        Markup.escape(self.text(i, attr_list)))
+        return '<a href="{url}">{text}</a>'.format(
+            url=self.url(i),
+            text=Markup.escape(self.text(i, attr_list)))
 
 
 class ButtonCol(LinkCol):
@@ -218,7 +226,8 @@ class ButtonCol(LinkCol):
     """
 
     def td_contents(self, i, attr_list):
-        return ('<form method="post" action="%s">'
-                '<button type="submit">%s</button>'
-                '</form>') % (self.url(i),
-                              Markup.escape(self.text(i, attr_list)))
+        return '<form method="post" action="{url}">'\
+            '<button type="submit">{text}</button>'\
+            '</form>'.format(
+                url=self.url(i),
+                text=Markup.escape(self.text(i, attr_list)))
