@@ -1,7 +1,9 @@
 # -*- coding: utf-8 -*-
-
+from __future__ import unicode_literals
 from collections import OrderedDict
+
 from flask import Markup
+
 from .columns import Col
 from .compat import with_metaclass
 
@@ -47,32 +49,32 @@ class Table(with_metaclass(TableMeta)):
         if not self.classes:
             return ''
         else:
-            return ' class="%s"' % ' '.join(self.classes)
+            return ' class="{}"'.format(' '.join(self.classes))
 
     def __html__(self):
         if len(self.items) == 0:
             return '<p>No Items</p>'
         else:
-            return '<table%s>%s\n%s</table>' % (
-                self.classes_html_attr(),
-                self.thead(), self.tbody())
+            return '<table{attrs}>{thead}\n{tbody}</table>'.format(
+                attrs=self.classes_html_attr(),
+                thead=self.thead(),
+                tbody=self.tbody())
 
     def thead(self):
-        return '<thead><tr>%s</tr></thead>' % ''.join(
-            (self.th(col_key, col) for col_key, col in self._cols.items())
-        )
+        return '<thead><tr>{}</tr></thead>'.format(''.join(
+            (self.th(col_key, col) for col_key, col in self._cols.items())))
 
     def tbody(self):
         out = []
         for i in self.items:
             out.append(self.tr(i))
-        return '<tbody>%s</tbody>' % ''.join(out)
+        return '<tbody>{}</tbody>'.format(''.join(out))
 
     def tr(self, i):
         out = []
         for attr, c in self._cols.items():
             out.append(c.td(i, attr))
-        return '<tr>%s</tr>' % ''.join(out)
+        return '<tr>{}</tr>'.format(''.join(out))
 
     def th_contents(self, col_key, col):
         escaped = Markup.escape(col.name)
@@ -81,14 +83,17 @@ class Table(with_metaclass(TableMeta)):
 
         if self.sort_by == col_key:
             if self.sort_reverse:
-                return u'<a href="{}">↑{}</a>'.format(self.sort_url(col_key), escaped)
+                return '<a href="{}">↑{}</a>'.format(
+                    self.sort_url(col_key), escaped)
             else:
-                return u'<a href="{}">↓{}</a>'.format(self.sort_url(col_key, reverse=True), escaped)
+                return '<a href="{}">↓{}</a>'.format(
+                    self.sort_url(col_key, reverse=True), escaped)
         else:
-            return u'<a href="{}">{}</a>'.format(self.sort_url(col_key), escaped)
+            return '<a href="{}">{}</a>'.format(
+                self.sort_url(col_key), escaped)
 
     def th(self, col_key, col):
-        return u'<th>{}</th>'.format(self.th_contents(col_key, col))
+        return '<th>{}</th>'.format(self.th_contents(col_key, col))
 
     def sort_url(self, col_id, reverse=False):
         raise NotImplementedError('sort_url not implemented')
